==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/addressbook/language/nl.php <==
<?php


$l['name'] = 'Adresboek';
$l['description'] = 'Module om alle contacten te beheren.';
$l['allAddressbooks'] = 'Alle Adresboeken';
$lang['common']['addressbookAlreadyExists'] = 'Het adresboek wat je probeert te maken bestaat al';
$l['notIncluded'] = 'Niet importeren';
$l['comment'] = 'Opmerking';
$l['bankNo'] = 'Bankrekeningnummer'; ;
$l['vatNo'] = 'BTW-nummer';
$l['contactsGroup'] = 'Groep';
$lang['link_type'][2]=$l['contact'] = 'Contact';
$lang['link_type'][3]=$l['company'] = 'Bedrijf';
$l['customers'] = 'Klanten';
$l['suppliers'] = 'Leveranciers';
$l['prospects'] = 'Potentiële klanten';
$l['contacts']= 'Contactpersonen';
$l['companies']= 'Bedrijven';
$l['newContactAdded']='Nieuw contactpersoon toegevoegd';
$l['newContactFromSite']='Een nieuw contactpersoon was via een websiteformulier toegevoegd';
$l['clickHereToView']='Klik hier om de contactpersoon te bekijken';
$l['contactFromAddressbook']='Contactpersoon uit %s';
$l['companyFromAddressbook']='Bedrijf uit %s';
$l['defaultSalutationTpl']='Geachte [heer/mevrouw] {middle_name} {last_name}';
$l['multipleSelected']='Meerdere adresboeken geselecteerd';
$l['incomplete_delete_contacts']='U heeft niet voldoende rechten om alle geselecteerde contacten te verwijderen';
$l['incomplete_delete_companies']='U heeft niet voldoende rechten om alle geselecteerde bedrijven te verwijderen';
$l['emailAlreadyExists']='E-mail adres is al toegevoegd aan deze contactpersoon';
$l['emailDoesntExists']='E-mail adres is niet gevonden';
$l['imageNotSupported']='De afbeelding die u stuurde wordt niet ondersteund. Alleen gif, png en jpg afbeeldingen worden ondersteund.';
$l['no_addressbook_id'] = 'Onjuiste adresboek-id werd naar de server gestuurd!';
$l['undefined'] = '-';
$l["savedQueries"]='Opgeslagen zoekopdrachten';
$l["newSearch"]='Nieuwe zoekopdracht';
$l["executeQuery"]='Zoekopdracht uitvoeren';
$l["selectField"]= 'Selecteer veld';
$l["cmdFormLabelAddressBooks"]= 'Adresboek';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
$l["cmdAllFields"]= 'Alle velden';
$l["btnAddContact"]= 'Contact toevoegen'	;
$l["btnAddCompany"]= 'Bedrijf toevoegen';
$l["btnManage"]= 'Beheren';
$l["btnDownload"]= 'Download bestand';
$l["cmdFormSearchFirst"]= 'Zoeken in= ';
$l["cmdFormSearchSecond"]= ' op= ';
$l["cmdFormSearchThird"]= ' voor= ';
$l["cmdFormSearchFourth"]= '(Gebruik \'%\' als joker) ';
$l["cmdFormLabelTitleInitials"]= 'Titel/Initialen';
$l["cmdFormLabelSalutation"]= 'Aanhef';
$l["cmdFormLabelComment"]= 'Opmerking';
$l["cmdFormCompanyEmptyText"]= 'Selecteer een bedrijf';
$l["cmdFieldsetSelectAddressbook"]= 'Selecteer een adresboek';
$l["cmdFieldsetPersonalDetails"]= 'Persoonlijke gegevens';
$l["cmdFieldsetAddress"]= 'Adres';
$l["cmdFieldsetContact"]= 'Contact gegevens';
$l["cmdFieldsetWork"]= 'Werk';
$l["cmdPanelContact"]= 'Contact gegevens';
$l["cmdPanelComments"]= 'Opmerkingen';
$l["cmdContactDialog"]= 'Contact aanpassen';
$l["contact"]= 'Contact';
$l["cmdSalutation"]= 'Geachte';
$l["cmdMadam"]= 'mevrouw';
$l["cmdSir"]= 'heer';
$l["btnDownloadTextDocument"]= 'Download tekstdocument';
$l["cmdContactDetailsFor"]= 'Persoonlijke gegevens voor';
$l["cmdLInkFieldset"]= 'Links';
$l["company"]= 'Bedrijf';
$l["cmdCompanyDetailsFor"]= 'Details voor';
$l["cmdPanelCompany"]= 'Bedrijfsgegevens';
$l["cmdFormLabelBankNo"]= 'Bankrekeningnummer';
$l["cmdFormLabelVatNo"]= 'BTW-nummer';
$l["cmdFormLabelInvoiceEmail"]= 'Factuuremail';
$l["cmdFieldsetCompanyDetails"]= 'Bedrijfsgegevens';
$l["cmdFieldsetVisitAddress"]= 'Bezoekadres';
$l["cmdFieldsetPostAddress"]= 'Postadres';
$l["cmdCompanyDialog"]= 'Bedrijf aanpassen';
$l["cmdPanelEmployees"]= 'Werknemers';
$l["cmdPanelEmployee"]= 'Werknemer';
$l["cmdAllEmployeesForThisCompany"]= 'Alle werknemers voor dit bedrijf';
$l["cmdFieldsetVisitAddress"]= 'Bezoekadres';
$l["cmdFieldsetPostAddress"]= 'Postadres';
$l["cmdManageDialog"]= 'Beheren';
$l["cmdAddAddressBook"]= 'Adresboek aanpassen';
$l["cmdDeleteAddressbook"]= 'Adresboek verwijderen';
$l["cmdOwner"]= 'Eigenaar';
$l["cmdPanelAddressbook"]= 'Adresboeken';
$l["cmdPanelProperties"]= 'Eigenschappen';
$l["cmdContactDialog"]= 'Contact aanpassen';
$l["cmdFormLabelFileType"]= 'Bestandstype';
$l["cmdFormLabelFile"]= 'Bestand';	;
$l["cmdFormLabelValueSeperated"]= 'Waardes gescheiden door';
$l["cmdFormLabelValueIncluded"]= 'Waardes omsloten door';
$l["cmdFormLabelLinesEnded"]= 'Regeleinde door';
$l["cmdUpload"]= 'Upload';
$l["cmdImport"]= 'Importeren';
$l["cmdExport"]= 'Exporteren';
$l["cmdType"]= 'Type';
$l["contacts"]= 'Contacten';
$l["companies"]= 'Bedrijven';
$l["users"]= 'Gebruikers';
$l["noAddressbooks"]= 'Er zijn geen adresboeken';
$l["moveAll"]= 'Het bedrijf en al zijn werknemers zullen ook naar het nieuwe adresboek worden verplaatst. Weet u zeker dat u door wilt gaan?';
$l["addressbook"]= 'Adresboek';
$l["addressbooks"]= 'Adresboeken';
$l["sendMailing"]='Nieuwsbrief versturen';
$l["importSuccessCount"]='Gegevens die succesvol zijn geïmporteerd:';
$l["importSuccess"]='Gegevens succesvol geïmporteerd!';
$l["searchOnSender"]='Opzoeken in adresboek';
$l["confirmCreate"]='Contactpersoon niet gevonden. Wilt u een nieuw contactpersoon aanmaken?';
$l["selectMailingGroup"]='Selecteer adreslijst';
$l["strSelectContact"]= 'Selecteer contactpersoon';
$l["strSelectCompany"]= 'Selecteer bedrijf';
$l["matchFields"]='Koppel de velden';
$l["advancedSearch"]='Geavanceerd zoeken';
$l["defaultAddressFormat"]='Standaard adres formaat';
$l["defaultSalutation"]='Standaard aanhef';
$l["explanationVariables"]='Uitleg standaard aanhef variabelen';
$l["explanationSex"]='Mannelijke en vrouwelijke vormen van de aanhef';
$l["searchQueryName"]='Naam zoekterm';
$l["enterSearchQueryName"]='Geef een naam aan deze zoekterm:';
$l["photo"]= 'Foto';
$l["deleteImage"]='Verwijder afbeelding';
$l["addAllSearchResults"]='Alle zoekresultaten toevoegen';
$l["confirmAddAllSearchResults"]='Weet u zeker dat u alle zoekresultaten aan de adreslijst wilt toevoegen?';
$l["emailAdded"]='Emailadres succesvol toegevoegd aan contactpersoon';
$l["exportWithCompanies"]='Met bedrijven';
$l["id"]='ID';
$l["exportPermission"]='Export rechten';
$l["crn"]='KvK nr.';
$l["iban"]='IBAN';
$l["unknownEmail"]= 'Onbekend emailadres';
$l["strUnknownEmail"]= 'Dit emailadres is onbekend. Wilt u dit toevoegen bij een nieuw contact, verwerken in een bestaand contact, of annuleren?';
$l["globalsettings_templatelabel"]= 'Naam template';
$l["globalsettings_allchangelabel"]= 'Bestaande veranderen?';
$l["globalsettings_renameall"]= 'Weet u zeker dat u alles wilt hernoemen?';
$l["createEmailSelected"]= 'Email opstellen voor selectie';
$l['createUser'] = 'Gebruiker aanmaken';
$l['addresslist'] = 'Adreslijst';
$l['addresslistContact'] = 'Adreslijstcontact';

$l["emailTemplate"]= 'E-mail sjabloon';
$l["cmdPanelTemplate"]= 'Sjablonen';
$l["cmdAddEmailTemplate"]= 'E-mail sjabloon toevoegen';
$l["addDocumentTemplate"]='Documentsjabloon toevoegen';
$l["documentTemplate"]='Documentsjabloon';
$l["cmdType"]= 'Type';
$l['unsubscribe']='Uitschrijven';
$l['unsubscription']='Klik hier om uit te schrijven van deze nieuwsbrief.';
$l["autoDataMyName"]= 'Mijn naam';
$l["autoDataBeginning"]= 'Begin';
$l["autoData"]= 'Autodata';
$l["customContactFields"]='Extra velden contactpersonen';
$l["customCompanyFields"]='Extra velden bedrijven';
$l["customUserFields"]='Extra velden gebruikers';

$l["cmdPanelTemplate"] = 'Sjablonen';
$l["cmdAddEmailTemplate"]= 'E-mail sjabloon toevoegen';
$l["cmdAddOpenOfficeTemplate"]= 'OpenOffice.org sjabloon toevoegen';
$l["cmdType"]= 'Type';
$l["cmdTemplateDialog"]= 'Sjabloon aanpassen';
$l["cmdFormLabelReadNotification"]= 'Verzoek de ontvanger een leesbevestiging te sturen';
$l["cmdAddMailing"]= 'Adreslijst toevoegen';
$l["cmdDeleteMailing"]= 'Adreslijst verwijderen';
$l["cmdPanelMailings"]= 'Adreslijsten';
$l["cmdEditMailingWindow"]= 'Adreslijst aanpassen';
$l["SelectOODocument"]= 'Selecteer een sjabloon';
$l["SelectOODocumentWindowTitle"]= 'Selecteer OpenOffice document';
$l["autoDataMyName"] = 'Mijn naam';
$l["autoDataBeginning"] = 'Begin';
$l["emailTemplate"] = 'E-mail sjabloon';
$l["sendingEmailAllowed"] = 'Het is toegestaan mailings naar dit e-mail adres te sturen';
$l["enabledMailingGroups"] = 'Ingeschakelde mailing groepen:';
$l["autoData"]= 'Autodata';
$l["selectMailingGroup"]='Selecteer een adreslijst';
$l["noMailingGroups"]='U heeft geen adreslijsten';
$l["sentMailings"]='Verzonden nieuwsbrieven';

$l["subject"]='Onderwerp';
$l["status"]='Status';
$l["sent"]='Verzonden';
$l["total"]='Totaal';
$l["errors"]='Fouten';

$l["addEntireAddressbook"]='Geheel adresboek toevoegen';
$l["selectAddressbook"]='Selecteer een adresboek';
$l["defaultSalutationText"]='Voer een standaard aanhef in die wordt gebruikt wanneer de aanhef niet bepaald kan worden';
$l["filterMailings"]='Adreslijst filter';

$l["enterName"]='Geef bestandsnaam';
$l["pleaseEnterName"]='Voer een bestandnaam in voor het nieuwe document a.u.b.';
$l["noAddressLists"]='Geen adreslijsten';

$l["confirmAddEntireAddressbook"]='Weet u zeker dat u alles uit dit adresboek wilt toevoegen aan deze adreslijst?';
$l["noTemplate"]='Geen sjabloon';

$l["customContactFields"]='Extra velden contactpersonen';
$l["customCompanyFields"]='Extra velden bedrijven';
$l["customUserFields"]='Extra velden gebruikers';
$l["newsletters"]='Nieuwsbrieven';

$l["addresslist"]='Adreslijst';

$l["viewLog"]='Bekijk logbestand';
$l["viewMessage"]='Bekijk bericht';
$l["pauseMailing"]='Pauzeer verzenden';
$l["resumeMailing"]='Doorgaan met verzenden';
$l["unsubscribeLink"]='Uitschrijflink';
$l["unsubscribeHref"]='Uitschrijf href';

$l["addDocumentTemplate"]='Documentsjabloon toevoegen';
$l["documentTemplate"]='Documentsjabloon';

$l["copyingMessages"]='Bezig met kopiëren van berichten...';
$l['editUser']='Bewerk gebruiker';
$l['template']='Sjabloon';

$l['addresslistIdMustBePositive']='Dit paneel verwacht een adreslijst ID die positief is, maar heeft zo een niet ontvangen. Neemt u a.u.b. contact op met de beheerder.';
$l['male']='Man';
$l['female']='Vrouw';
$l['importing']='Importeren';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/addressbook/language/nl.php <==
<?php


$l['name'] = 'Adresboek';
$l['description'] = 'Module om alle contacten te beheren.';
$l['allAddressbooks'] = 'Alle Adresboeken';
$lang['common']['addressbookAlreadyExists'] = 'Het adresboek wat je probeert te maken bestaat al';
$l['notIncluded'] = 'Niet importeren';
$l['comment'] = 'Opmerking';
$l['bankNo'] = 'Bankrekeningnummer'; ;
$l['vatNo'] = 'BTW-nummer';
$l['contactsGroup'] = 'Groep';
$lang['link_type'][2]=$l['contact'] = 'Contact';
$lang['link_type'][3]=$l['company'] = 'Bedrijf';
$l['customers'] = 'Klanten';
$l['suppliers'] = 'Leveranciers';
$l['prospects'] = 'Potentiële klanten';
$l['contacts']= 'Contactpersonen';
$l['companies']= 'Bedrijven';
$l['newContactAdded']='Nieuw contactpersoon toegevoegd';
$l['newContactFromSite']='Nieuwe gegevens van een contactpersoon zijn via een websiteformulier toegevoegd';
$l['clickHereToView']='Klik hier om de contactpersoon te bekijken';
$l['contactFromAddressbook']='Contactpersoon uit %s';
$l['companyFromAddressbook']='Bedrijf uit %s';
$l['defaultSalutationTpl']='Geachte [heer/mevrouw] {middle_name} {last_name}';
$l['multipleSelected']='Meerdere adresboeken geselecteerd';
$l['incomplete_delete_contacts']='U heeft niet voldoende rechten om alle geselecteerde contacten te verwijderen';
$l['incomplete_delete_companies']='U heeft niet voldoende rechten om alle geselecteerde bedrijven te verwijderen';
$l['emailAlreadyExists']='E-mail adres is al toegevoegd aan deze contactpersoon';
$l['emailDoesntExists']='E-mail adres is niet gevonden';
$l['imageNotSupported']='De afbeelding die u stuurde wordt niet ondersteund. Alleen gif, png en jpg afbeeldingen worden ondersteund.';
$l['no_addressbook_id'] = 'Onjuiste adresboek-id werd naar de server gestuurd!';
$l['undefined'] = '-';
$l["savedQueries"]='Opgeslagen zoekopdrachten';
$l["newSearch"]='Nieuwe zoekopdracht';
$l["executeQuery"]='Zoekopdracht uitvoeren';
$l["selectField"]= 'Selecteer veld';
$l["cmdFormLabelAddressBooks"]= 'Adresboek';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
$l["cmdAllFields"]= 'Alle velden';
$l["btnAddContact"]= 'Contact toevoegen'	;
$l["btnAddCompany"]= 'Bedrijf toevoegen';
$l["btnManage"]= 'Beheren';
$l["btnDownload"]= 'Download bestand';
$l["cmdFormSearchFirst"]= 'Zoeken in= ';
$l["cmdFormSearchSecond"]= ' op= ';
$l["cmdFormSearchThird"]= ' voor= ';
$l["cmdFormSearchFourth"]= '(Gebruik \'%\' als joker) ';
$l["cmdFormLabelTitleInitials"]= 'Titel/Initialen';
$l["cmdFormLabelSalutation"]= 'Aanhef';
$l["cmdFormLabelComment"]= 'Opmerking';
$l["cmdFormCompanyEmptyText"]= 'Selecteer een bedrijf';
$l["cmdFieldsetSelectAddressbook"]= 'Selecteer een adresboek';
$l["cmdFieldsetPersonalDetails"]= 'Persoonlijke gegevens';
$l["cmdFieldsetAddress"]= 'Adres';
$l["cmdFieldsetContact"]= 'Contact gegevens';
$l["cmdFieldsetWork"]= 'Werk';
$l["cmdPanelContact"]= 'Contact gegevens';
$l["cmdPanelComments"]= 'Opmerkingen';
$l["cmdContactDialog"]= 'Contact aanpassen';
$l["contact"]= 'Contact';
$l["cmdSalutation"]= 'Geachte';
$l["cmdMadam"]= 'mevrouw';
$l["cmdSir"]= 'heer';
$l["btnDownloadTextDocument"]= 'Download tekstdocument';
$l["cmdContactDetailsFor"]= 'Persoonlijke gegevens voor';
$l["cmdLInkFieldset"]= 'Links';
$l["company"]= 'Bedrijf';
$l["cmdCompanyDetailsFor"]= 'Details voor';
$l["cmdPanelCompany"]= 'Bedrijfsgegevens';
$l["cmdFormLabelBankNo"]= 'Bankrekeningnummer';
$l["cmdFormLabelVatNo"]= 'BTW-nummer';
$l["cmdFormLabelInvoiceEmail"]= 'Factuuremail';
$l["cmdFieldsetCompanyDetails"]= 'Bedrijfsgegevens';
$l["cmdFieldsetVisitAddress"]= 'Bezoekadres';
$l["cmdFieldsetPostAddress"]= 'Postadres';
$l["cmdCompanyDialog"]= 'Bedrijf aanpassen';
$l["cmdPanelEmployees"]= 'Werknemers';
$l["cmdPanelEmployee"]= 'Werknemer';
$l["cmdAllEmployeesForThisCompany"]= 'Alle werknemers voor dit bedrijf';
$l["cmdFieldsetVisitAddress"]= 'Bezoekadres';
$l["cmdFieldsetPostAddress"]= 'Postadres';
$l["cmdManageDialog"]= 'Beheren';
$l["cmdAddAddressBook"]= 'Adresboek aanpassen';
$l["cmdDeleteAddressbook"]= 'Adresboek verwijderen';
$l["cmdOwner"]= 'Eigenaar';
$l["cmdPanelAddressbook"]= 'Adresboeken';
$l["cmdPanelProperties"]= 'Eigenschappen';
$l["cmdContactDialog"]= 'Contact aanpassen';
$l["cmdFormLabelFileType"]= 'Bestandstype';
$l["cmdFormLabelFile"]= 'Bestand';	;
$l["cmdFormLabelValueSeperated"]= 'Waardes gescheiden door';
$l["cmdFormLabelValueIncluded"]= 'Waardes omsloten door';
$l["cmdFormLabelLinesEnded"]= 'Regeleinde door';
$l["cmdUpload"]= 'Upload';
$l["cmdImport"]= 'Importeren';
$l["cmdExport"]= 'Exporteren';
$l["cmdType"]= 'Type';
$l["contacts"]= 'Contacten';
$l["companies"]= 'Bedrijven';
$l["users"]= 'Gebruikers';
$l["noAddressbooks"]= 'Er zijn geen adresboeken';
$l["moveAll"]= 'Het bedrijf en al zijn werknemers zullen ook naar het nieuwe adresboek worden verplaatst. Weet u zeker dat u door wilt gaan?';
$l["addressbook"]= 'Adresboek';
$l["addressbooks"]= 'Adresboeken';
$l["sendMailing"]='Nieuwsbrief versturen';
$l["importSuccessCount"]='Gegevens die succesvol zijn geïmporteerd:';
$l["importSuccess"]='Gegevens succesvol geïmporteerd!';
$l["searchOnSender"]='Opzoeken in adresboek';
$l["confirmCreate"]='Contactpersoon niet gevonden. Wilt u een nieuw contactpersoon aanmaken?';
$l["selectMailingGroup"]='Selecteer adreslijst';
$l["strSelectContact"]= 'Selecteer contactpersoon';
$l["strSelectCompany"]= 'Selecteer bedrijf';
$l["matchFields"]='Koppel de velden';
$l["advancedSearch"]='Geavanceerd zoeken';
$l["defaultAddressFormat"]='Standaard adres formaat';
$l["defaultSalutation"]='Standaard aanhef';
$l["explanationVariables"]='Uitleg standaard aanhef variabelen';
$l["explanationSex"]='Mannelijke en vrouwelijke vormen van de aanhef';
$l["searchQueryName"]='Naam zoekterm';
$l["enterSearchQueryName"]='Geef een naam aan deze zoekterm:';
$l["photo"]= 'Foto';
$l["deleteImage"]='Verwijder afbeelding';
$l["addAllSearchResults"]='Alle zoekresultaten toevoegen';
$l["confirmAddAllSearchResults"]='Weet u zeker dat u alle zoekresultaten aan de adreslijst wilt toevoegen?';
$l["emailAdded"]='Emailadres succesvol toegevoegd aan contactpersoon';
$l["exportWithCompanies"]='Met bedrijven';
$l["id"]='ID';
$l["exportPermission"]='Export rechten';
$l["crn"]='KvK nr.';
$l["iban"]='IBAN';
$l["unknownEmail"]= 'Onbekend emailadres';
$l["strUnknownEmail"]= 'Dit emailadres is onbekend. Wilt u dit toevoegen bij een nieuw contact, verwerken in een bestaand contact, of annuleren?';
$l["globalsettings_templatelabel"]= 'Naam template';
$l["globalsettings_allchangelabel"]= 'Bestaande veranderen?';
$l["globalsettings_renameall"]= 'Weet u zeker dat u alles wilt hernoemen?';
$l["createEmailSelected"]= 'Email opstellen voor selectie';
$l['createUser'] = 'Gebruiker aanmaken';
$l['addresslist'] = 'Adreslijst';
$l['addresslistContact'] = 'Adreslijstcontact';

$l["emailTemplate"]= 'E-mail sjabloon';
$l["cmdPanelTemplate"]= 'Sjablonen';
$l["cmdAddEmailTemplate"]= 'E-mail sjabloon toevoegen';
$l["addDocumentTemplate"]='Documentsjabloon toevoegen';
$l["documentTemplate"]='Documentsjabloon';
$l["cmdType"]= 'Type';
$l['unsubscribe']='Uitschrijven';
$l['unsubscription']='Klik hier om uit te schrijven van deze nieuwsbrief.';
$l["autoDataMyName"]= 'Mijn naam';
$l["autoDataBeginning"]= 'Begin';
$l["autoData"]= 'Autodata';
$l["customContactFields"]='Extra velden contactpersonen';
$l["customCompanyFields"]='Extra velden bedrijven';
$l["customUserFields"]='Extra velden gebruikers';

$l["cmdPanelTemplate"] = 'Sjablonen';
$l["cmdAddEmailTemplate"]= 'E-mail sjabloon toevoegen';
$l["cmdAddOpenOfficeTemplate"]= 'OpenOffice.org sjabloon toevoegen';
$l["cmdType"]= 'Type';
$l["cmdTemplateDialog"]= 'Sjabloon aanpassen';
$l["cmdFormLabelReadNotification"]= 'Verzoek de ontvanger een leesbevestiging te sturen';
$l["cmdAddMailing"]= 'Adreslijst toevoegen';
$l["cmdDeleteMailing"]= 'Adreslijst verwijderen';
$l["cmdPanelMailings"]= 'Adreslijsten';
$l["cmdEditMailingWindow"]= 'Adreslijst aanpassen';
$l["SelectOODocument"]= 'Selecteer een sjabloon';
$l["SelectOODocumentWindowTitle"]= 'Selecteer OpenOffice document';
$l["autoDataMyName"] = 'Mijn naam';
$l["autoDataBeginning"] = 'Begin';
$l["emailTemplate"] = 'E-mail sjabloon';
$l["sendingEmailAllowed"] = 'Het is toegestaan mailings naar dit e-mail adres te sturen';
$l["enabledMailingGroups"] = 'Ingeschakelde mailing groepen:';
$l["autoData"]= 'Autodata';
$l["selectMailingGroup"]='Selecteer een adreslijst';
$l["noMailingGroups"]='U heeft geen adreslijsten';
$l["sentMailings"]='Verzonden nieuwsbrieven';

$l["subject"]='Onderwerp';
$l["status"]='Status';
$l["sent"]='Verzonden';
$l["total"]='Totaal';
$l["errors"]='Fouten';

$l["addEntireAddressbook"]='Geheel adresboek toevoegen';
$l["selectAddressbook"]='Selecteer een adresboek';
$l["defaultSalutationText"]='Voer een standaard aanhef in die wordt gebruikt wanneer de aanhef niet bepaald kan worden';
$l["filterMailings"]='Adreslijst filter';

$l["enterName"]='Geef bestandsnaam';
$l["pleaseEnterName"]='Voer een bestandnaam in voor het nieuwe document a.u.b.';
$l["noAddressLists"]='Geen adreslijsten';

$l["confirmAddEntireAddressbook"]='Weet u zeker dat u alles uit dit adresboek wilt toevoegen aan deze adreslijst?';
$l["noTemplate"]='Geen sjabloon';

$l["customContactFields"]='Extra velden contactpersonen';
$l["customCompanyFields"]='Extra velden bedrijven';
$l["customUserFields"]='Extra velden gebruikers';
$l["newsletters"]='Nieuwsbrieven';

$l["addresslist"]='Adreslijst';

$l["viewLog"]='Bekijk logbestand';
$l["viewMessage"]='Bekijk bericht';
$l["pauseMailing"]='Pauzeer verzenden';
$l["resumeMailing"]='Doorgaan met verzenden';
$l["unsubscribeLink"]='Uitschrijflink';
$l["unsubscribeHref"]='Uitschrijf href';

$l["addDocumentTemplate"]='Documentsjabloon toevoegen';
$l["documentTemplate"]='Documentsjabloon';

$l["copyingMessages"]='Bezig met kopiëren van berichten...';
$l['editUser']='Bewerk gebruiker';
$l['template']='Sjabloon';

$l['addresslistIdMustBePositive']='Dit paneel verwacht een adreslijst ID die positief is, maar heeft zo een niet ontvangen. Neemt u a.u.b. contact op met de beheerder.';
$l['male']='Man';
$l['female']='Vrouw';
$l['importing']='Importeren';

$l['nRemovedFromAddresslist']='%n contacten zijn herkend en verwijderd uit de geselecteerde adreslijst.';

$l['addToAddresslist']='Toevoegen aan adreslijst %s';
$l['addToAddresslistPrompt']='U staat op het punt om de geselecteerde items toe te voegen aan adreslijst %s. Wilt u dat deze items alleen voorkomen in %s?';
$l['addAddresslistSuccess']='De items zijn met succes toegevoegd aan de adreslijst.';
